{% extends "django_opt_out/base.html" %}
{% load i18n %}

{% block content %}
    <div class="container">
        <div class="row">
            <div class="col-md-8 offset-md-2">
                <div class="card">
                    <h4 class="card-header">{% blocktrans %}Set language{% endblocktrans %}</h4>
                    <div class="card-body">
                        <form action="{% url 'set_language' %}" method="post">{% csrf_token %}
                            <input name="next" type="hidden" value="{{ redirect_to }}"/>
                            <select name="language">
                                {% get_current_language as LANGUAGE_CODE %}
                                {% get_available_languages as LANGUAGES %}
                                {% get_language_info_list for LANGUAGES as languages %}
                                {% for language in languages %}
                                    <option value="{{ language.code }}"{% if language.code == LANGUAGE_CODE %} selected{% endif %}>
                                        {{ language.name_local }} ({{ language.code }})
                                    </option>
                                {% endfor %}
                            </select>
                            <input type="submit" value="{% blocktrans %}Save language{% endblocktrans %}"/>
                        </form>
                    </div>
                </div>
            </div>
        </div>
    </div>
{% endblock %}
