{% load staticfiles i18n %}<!DOCTYPE html>
<html lang="en">
<head>
    <!-- Required meta tags -->
    <meta charset="utf-8">
    <meta name="viewport" content="width=device-width, initial-scale=1, shrink-to-fit=no">
    <title>{% block title %}Django Opt-out application{% endblock title %}</title>

    <!-- Bootstrap CSS -->
    <link rel="stylesheet" href="https://maxcdn.bootstrapcdn.com/bootstrap/4.0.0-beta.2/css/bootstrap.min.css"
          integrity="sha384-PsH8R72JQ3SOdhVi3uxftmaW6Vc51MKb0q5P2rRUpPvrszuE4W1povHYgTpBfshb"
          crossorigin="anonymous">
    <style>
        body {
            background-color: #FFFFFF;
        }
    </style>
    <script src="https://use.fontawesome.com/900b3fb674.js"></script>
</head>
<body>
<nav class="navbar navbar-expand-lg navbar-dark bg-dark mb-4">
    <div class="container">
        <a class="navbar-brand" href="/">django-opt-out </a>
        <button class="navbar-toggler navbar-toggler-right" type="button" data-toggle="collapse" data-target="#navbarSupportedContent"
                aria-controls="navbarSupportedContent" aria-expanded="false"
                aria-label="Toggle navigation">
            <span class="navbar-toggler-icon"></span>
        </button>

        <div class="collapse navbar-collapse" id="navbarSupportedContent">
            <ul class="navbar-nav mr-auto">
                <li class="nav-item"><a class="nav-link" href="{% url "django_opt_out:OptOutConfirm" %}"><i class="fa fa-fw fa-th-list"></i> Opt Out form</a></li>
                <li class="nav-item"><a class="nav-link" href="{% url 'admin:index' %}"><i class="fa fa-fw fa-database"></i> {% blocktrans %}Django Admin{% endblocktrans %}</a></li>
                <li class="nav-item"><a class="nav-link" href="{% url 'language_form' %}"><i class="fa fa-fw fa-language"></i> {% blocktrans %}Set language{% endblocktrans %}</a></li>
                <li class="nav-item"><a class="nav-link" href="https://django-opt-out.readthedocs.io"><i class="fa fa-fw fa-book"></i> Docs</a></li>
                <li class="nav-item"><a class="nav-link" href="https://github.com/wooyek/django-opt-out.readthedocs.io"><i class="fa fa-fw fa-github"></i> Repo</a></li>
            </ul>
        </div>
    </div>
</nav>
{% if messages %}
    <div class="container">
        {% for message in messages %}
            <div class="alert {% if message.tags %}alert-{{ message.tags }}{% endif %}">{{ message }}</div>
        {% endfor %}
    </div>
{% endif %}
{% block content %}
    <div class="container">
        <div class="row">
            <div class="col">
                <div class="jumbotron my-4">
                    <h1 class="display-3">Hello, world!</h1>
                    <p class="lead">Use this document as a way to quick start any new project.</p>
                    <hr class="my-4">
                    <p>The current template is loaded from
                        <code>django-opt-out/project_example/templates/django_opt_out/base.html</code>. </p>
                    <p>Whenever you overwrite the contents of <code>django-opt-out/django_opt_out/urls.py</code> with your
                        own content, you should see it here.</p>
                    <p class="lead">
                        <a class="btn btn-primary btn-lg" href="https://django-opt-out.readthedocs.io" role="button">Learn more</a>
                    </p>
                </div>
            </div>
        </div>
    </div>
{% endblock content %}

<!-- jQuery first, then Tether, then Bootstrap JS. -->
<script src="https://code.jquery.com/jquery-3.2.1.slim.min.js" integrity="sha384-KJ3o2DKtIkvYIK3UENzmM7KCkRr/rE9/Qpg6aAZGJwFDMVNA/GpGFF93hXpG5KkN"
        crossorigin="anonymous"></script>
<script src="https://cdnjs.cloudflare.com/ajax/libs/popper.js/1.12.3/umd/popper.min.js"
        integrity="sha384-vFJXuSJphROIrBnz7yo7oB41mKfc8JzQZiCq4NCceLEaO4IHwicKwpJf9c9IpFgh" crossorigin="anonymous"></script>
<script src="https://maxcdn.bootstrapcdn.com/bootstrap/4.0.0-beta.2/js/bootstrap.min.js"
        integrity="sha384-alpBpkh1PFOepccYVYDB4do5UnbKysX5WZXm3XxPqe5iKTfUKjNkCk9SaVuEZflJ" crossorigin="anonymous"></script>
</body>
</html>
